/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.admin.ProjectAdminViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.FilteringTable");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.client.internal.ProjectClient");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");

var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var ProjectClient			= com.ibm.rational.report.web.core.client.internal.ProjectClient;
var InitializationData		= com.ibm.team.repository.web.client.init.InitializationData;
var session					= com.ibm.team.repository.web.client.session;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

/**
 * Displays the Manage Projects and Teams view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.admin.ProjectAdminViewer",
	[dijit._Widget, dijit._Templated],	{
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/admin/templates/ProjectAdminViewer.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
	},
	
	postCreate: function() {
		this._msgFormatter = new MessageFormatter(this.messageArea);
		
		this._tableColumns = [
			{field: "Name"},
			{field: "Description"}
		];
		
		this._table = new com.ibm.rational.report.web.core.app.internal.common.FilteringTable(
			{valueField: "rowId"}, this.projectTable);
			
		for (var i = 0; i < this._tableColumns.length; i++) {
			this._table.columns.push(this._table.createMetaData(this._tableColumns[i]));
		}
			
		dojo.connect(this._table, "onSelect", this, "_onTableSelect");
				
		this._refreshTable();
	},
	
	_refreshTable: function() {
		var srh = new ServiceResponseHandler(this, "_getProjectAreas", "_getProjectAreasError");				
		ProjectClient.getProjectAreas(srh);
	},
	
	_getProjectAreas: function(projectAreas) {
		for (var i = 0; i < projectAreas.length; i++) {
			var projectArea = projectAreas[i];
			this._table.store.addData({
				rowId: i,
				itemId: projectArea.itemId,
				Name: projectArea.name,
				Description: projectArea.descSummary,
				Select: "<input type=\"checkbox\" id=\"" + projectArea.itemId + ">"
			});
		}		
	},
	
	_getProjectAreasError: function(error) {
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_PROJECTS, error);		
	},
	
	_onTableSelect: function() {		
		var data = this._table.getSelectedData();
		this._controller.editProject(data);
	}
	
});

})();